@@ -6,7 +6,7 @@ package Excel::Writer::XLSX::Package::Styles;
 #
 # Used in conjunction with Excel::Writer::XLSX
 #
-# Copyright 2000-2019, John McNamara, jmcnamara@cpan.org
+# Copyright 2000-2020, John McNamara, jmcnamara@cpan.org
 #
 # Documentation after __END__
 #
@@ -20,7 +20,7 @@ use Carp;
 use Excel::Writer::XLSX::Package::XMLwriter;
 
 our @ISA     = qw(Excel::Writer::XLSX::Package::XMLwriter);
-our $VERSION = '1.03';
+our $VERSION = '1.04';
 
 
 ###############################################################################
@@ -52,6 +52,7 @@ sub new {
     $self->{_dxf_formats}        = [];
     $self->{_has_hyperlink}      = 0;
     $self->{_hyperlink_font_id}  = 0;
+    $self->{_has_comments}       = 0;
 
     bless $self, $class;
 
@@ -130,6 +131,7 @@ sub _set_style_properties {
     $self->{_fill_count}         = shift;
     $self->{_custom_colors}      = shift;
     $self->{_dxf_formats}        = shift;
+    $self->{_has_comments}       = shift;
 }
 
 
@@ -303,6 +305,11 @@ sub _write_fonts {
     my $self  = shift;
     my $count = $self->{_font_count};
 
+    if ( $self->{_has_comments} ) {
+        # Add an extra font for comments.
+        $count++;
+    }
+
     my @attributes = ( 'count' => $count );
 
     $self->xml_start_tag( 'fonts', @attributes );
@@ -312,6 +319,10 @@ sub _write_fonts {
         $self->_write_font( $format ) if $format->{_has_font};
     }
 
+    if ( $self->{_has_comments} ) {
+        $self->_write_comment_font();
+    }
+
     $self->xml_end_tag( 'fonts' );
 }
 
@@ -402,6 +413,25 @@ sub _write_font {
     $self->xml_end_tag( 'font' );
 }
 
+##############################################################################
+#
+# _write_comment_font()
+#
+# Write the <font> element used for comments.
+#
+sub _write_comment_font {
+
+    my $self = shift;
+
+    $self->xml_start_tag( 'font' );
+
+    $self->xml_empty_tag( 'sz', 'val', 8 );
+    $self->_write_color( 'indexed' => 81 );
+    $self->xml_empty_tag( 'name',   'val', 'Tahoma' );
+    $self->xml_empty_tag( 'family', 'val', 2 );
+
+    $self->xml_end_tag( 'font' );
+}
 
 ###############################################################################
 #
@@ -798,16 +828,8 @@ sub _write_cell_xfs {
 
     my $self    = shift;
     my @formats = @{ $self->{_xf_formats} };
+    my $count   = scalar @formats;
 
-    # Workaround for when the last format is used for the comment font
-    # and shouldn't be used for cellXfs.
-    my $last_format = $formats[-1];
-
-    if ( $last_format->{_font_only} ) {
-        pop @formats;
-    }
-
-    my $count = scalar @formats;
     my @attributes = ( 'count' => $count );
 
     $self->xml_start_tag( 'cellXfs', @attributes );
@@ -1166,7 +1188,7 @@ John McNamara jmcnamara@cpan.org
 
 =head1 COPYRIGHT
 
-(c) MM-MMXIX, John McNamara.
+(c) MM-MMXX, John McNamara.
 
 All Rights Reserved. This module is free software. It may be used, redistributed and/or modified under the same terms as Perl itself.
 
